@@ -18,4 +18,20 @@ TRAITS = [
     # The virt driver supports attaching a network interface after boot and
     # specifying a device tag for the interface
     'ATTACH_INTERFACE_WITH_TAG',
+
+    # traits corresponding to the allowed values of "hw_vif_model"
+    # image metadata property
+    # https://github.com/openstack/nova/blob/1f74441/nova/network/model.py#L136-L149
+    'VIF_MODEL_E1000',
+    'VIF_MODEL_E1000E',
+    'VIF_MODEL_LAN9118',
+    'VIF_MODEL_NETFRONT',
+    'VIF_MODEL_NE2K_PCI',
+    'VIF_MODEL_PCNET',
+    'VIF_MODEL_RTL8139',
+    'VIF_MODEL_SPAPR_VLAN',
+    'VIF_MODEL_SRIOV',
+    'VIF_MODEL_VIRTIO',
+    'VIF_MODEL_VMXNET',
+    'VIF_MODEL_VMXNET3',
 ]
